@@ -39,8 +39,7 @@ void AzDmat::_reform(int new_row_num, int new_col_num,
   a.alloc(&column, col_num, eyec, "column"); 
   dummy_zero.reform(row_num);   
   
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     column[cx] = new AzDvect(this->row_num); 
   }
 }
@@ -60,8 +59,7 @@ void AzDmat::_set(const AzDmat *m_inp)
     a.alloc(&column, col_num, eyec, "column"); 
     dummy_zero.reform(row_num);   
   }
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     delete column[cx]; 
     column[cx] = new AzDvect(m_inp->col(cx)); 
   }
@@ -80,8 +78,7 @@ void AzDmat::initialize(const AzReadOnlyMatrix *inp)
   row_num = inp->rowNum(); 
 
   a.alloc(&column, col_num, eyec, "column"); 
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     column[cx] = new AzDvect(inp->col(cx)); 
   }
   dummy_zero.reform(row_num); 
@@ -94,8 +91,7 @@ void AzDmat::resize(int new_row_num, int new_col_num)
     resize(new_col_num); 
   }
   if (new_row_num != row_num) {
-    int col; 
-    for (col = 0; col < col_num; ++col) {
+    for (int col = 0; col < col_num; ++col) {
       column[col]->resize(new_row_num); 
     }
     row_num = new_row_num; 
@@ -117,8 +113,7 @@ void AzDmat::resize(int new_col_num)
 
   int old_col_num = col_num; 
   a.realloc(&column, new_col_num, eyec, "column"); 
-  int cx; 
-  for (cx = old_col_num; cx < new_col_num; ++cx) {
+  for (int cx = old_col_num; cx < new_col_num; ++cx) {
     column[cx] = new AzDvect(row_num); 
   }
   col_num = new_col_num; 
@@ -152,14 +147,12 @@ void AzDmat::_transpose(AzDmat *m_out,
 {
   m_out->reform(col_end - col_begin, row_num); 
 
-  int cx; 
-  for (cx = col_begin; cx < col_end; ++cx) {
+  for (int cx = col_begin; cx < col_end; ++cx) {
     if (column[cx] == NULL) {
       continue; 
     }
 
-    int rx; 
-    for (rx = 0; rx < row_num; ++rx) {
+    for (int rx = 0; rx < row_num; ++rx) {
       double val = column[cx]->get(rx); 
       if (val != 0) {
         m_out->set(cx - col_begin, rx, val); 
@@ -172,8 +165,7 @@ void AzDmat::_transpose(AzDmat *m_out,
 void AzDmat::transpose_from(const AzSmat *m_inp)
 {
   reform(m_inp->colNum(), m_inp->rowNum()); 
-  int cx; 
-  for (cx = 0; cx < m_inp->colNum(); ++cx) {
+  for (int cx = 0; cx < m_inp->colNum(); ++cx) {
     const AzSvect *v_inp = m_inp->col(cx); 
     AzCursor cursor; 
     for ( ; ; ) {
@@ -194,8 +186,7 @@ void AzDmat::_read(AzFile *file)
   row_num = file->readInt(); 
   if (col_num > 0) {
     a.alloc(&column, col_num, eyec, "column"); 
-    int cx; 
-    for (cx = 0; cx < col_num; ++cx) {
+    for (int cx = 0; cx < col_num; ++cx) {
       column[cx] = AzObjIOTools::read<AzDvect>(file); 
     }
   }
@@ -206,8 +197,7 @@ void AzDmat::write(AzFile *file)
 {
   file->writeInt(col_num); 
   file->writeInt(row_num); 
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     AzObjIOTools::write(column[cx], file); 
   }
 }
@@ -252,8 +242,7 @@ void AzDmat::add(const AzDmat *inp, double coeff)
     throw new AzException(eyec, "Shape doesn't match"); 
   }
 
-  int cx; 
-  for (cx = 0; cx < this->col_num; ++cx) {
+  for (int cx = 0; cx < this->col_num; ++cx) {
     if (inp->column[cx] == NULL) {
       continue; 
     }
@@ -275,8 +264,7 @@ void AzDmat::add(const AzSmat *inp, double coeff)
     throw new AzException(eyec, "Shape doesn't match"); 
   }
 
-  int cx; 
-  for (cx = 0; cx < this->col_num; ++cx) {
+  for (int cx = 0; cx < this->col_num; ++cx) {
     if (inp->isZero(cx)) {
       continue; 
     }
@@ -306,8 +294,7 @@ void AzDmat::multiply(int row, int col, double val)
 /*-------------------------------------------------------------*/
 void AzDmat::multiply(double val) 
 {
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     if (column[cx] != NULL) {
       column[cx]->multiply(val); 
     }
@@ -317,8 +304,7 @@ void AzDmat::multiply(double val)
 /*-------------------------------------------------------------*/
 void AzDmat::add(double val) 
 {
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     if (column[cx] != NULL) {
       column[cx]->add(val); 
     }
@@ -340,47 +326,6 @@ double AzDmat::get(int row, int col) const
   return column[col]->get(row); 
 }
 
-#if 0 
-/*-------------------------------------------------------------*/
-void AzDmat::dump(const AzOut &out, const char *header, 
-                     const AzStrArray *sp_row, 
-                     const AzStrArray *sp_col, 
-                     int cut_num) const
-{
-  if (out.isNull()) return; 
-
-  AzPrint o(out); 
-
-  const char *my_header = ""; 
-  if (header != NULL) my_header = header; 
-  o.writeln(my_header); 
-
-  /* (row,col)=(r,c)\n */
-  o.printBegin("", ""); 
-  o.print("(row,col)="); 
-  o.pair_inParen(row_num, col_num, ","); 
-  o.printEnd(); 
-
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
-    if (column[cx] == NULL) {
-      continue; 
-    }
-
-    /* column=cx (col_header) */
-    o.printBegin("", " ", "="); 
-    o.print("column", cx); 
-    if (sp_col != NULL) {
-      o.inParen(sp_col->c_str(cx)); 
-    }
-    o.printEnd();
-
-    column[cx]->dump(out, "", sp_row, cut_num); 
-  }
-  o.flush(); 
-}
-#endif 
- 
 /*-------------------------------------------------------------*/
 void AzDmat::dump(const AzOut &out, const char *header, 
                   int max_col, 
@@ -409,8 +354,7 @@ void AzDmat::dump(const AzOut &out, const char *header,
   }
   o.printEnd(); 
 
-  int cx; 
-  for (cx = 0; cx < c_num; ++cx) {
+  for (int cx = 0; cx < c_num; ++cx) {
     if (column[cx] == NULL) {
       continue; 
     }
@@ -432,8 +376,7 @@ void AzDmat::dump(const AzOut &out, const char *header,
 /*-------------------------------------------------------------*/
 void AzDmat::normalize() 
 {
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     if (column[cx] != NULL) {  
       column[cx]->normalize(); 
     }
@@ -443,8 +386,7 @@ void AzDmat::normalize()
 /*-------------------------------------------------------------*/
 void AzDmat::normalize1() 
 {
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     if (column[cx] != NULL) {
       column[cx]->normalize1(); 
     }
@@ -454,8 +396,7 @@ void AzDmat::normalize1()
 /*-------------------------------------------------------------*/
 void AzDmat::binarize()
 {
-  int col; 
-  for (col = 0; col < col_num; ++col) {
+  for (int col = 0; col < col_num; ++col) {
     if (column[col] != NULL) {
       column[col]->binarize(); 
     }
@@ -465,8 +406,7 @@ void AzDmat::binarize()
 /*-------------------------------------------------------------*/
 void AzDmat::binarize1()
 {
-  int col; 
-  for (col = 0; col < col_num; ++col) {
+  for (int col = 0; col < col_num; ++col) {
     if (column[col] != NULL) {
       column[col]->binarize1(); 
     }
@@ -476,8 +416,7 @@ void AzDmat::binarize1()
 /*-------------------------------------------------------------*/
 void AzDmat::cut(double min_val)
 {
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     if (column[cx] != NULL) {
       column[cx]->cut(min_val); 
     }
@@ -487,8 +426,7 @@ void AzDmat::cut(double min_val)
 /*-------------------------------------------------------------*/
 void AzDmat::zeroOut()
 {
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     if (column[cx] != NULL) {
       column[cx]->zeroOut(); 
     }
@@ -501,8 +439,7 @@ double AzDmat::max(int *out_row, int *out_col) const
   int max_row = -1, max_col = -1; 
 
   double max_val = 0; 
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     double local_max; 
     int local_rx; 
     if (column[cx] == NULL) {
@@ -534,19 +471,20 @@ void AzDmat::scale(const AzDmat *m, bool isInverse)
   if (m->rowNum() != row_num || m->colNum() != col_num) {
     throw new AzException("AzDmat::scale(dmat)", "shape mismatch"); 
   }
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     if (column[cx] == NULL) continue; 
-    if (m->column[cx] != NULL) column[cx]->scale(m->column[cx], isInverse); 
-    else                       column[cx]->zeroOut(); 
+    if (m->column[cx] != NULL) {
+      column[cx]->scale(m->column[cx], isInverse);
+    } else {
+      column[cx]->zeroOut();
+    }
   }
 }
 
 /*-------------------------------------------------------------*/
 void AzDmat::scale(const AzSvect *vect1, bool isInverse) 
 {
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     if (column[cx] != NULL) {
       column[cx]->scale(vect1, isInverse); 
     }
@@ -556,8 +494,7 @@ void AzDmat::scale(const AzSvect *vect1, bool isInverse)
 /*-------------------------------------------------------------*/
 void AzDmat::scale(const AzDvect *vect1, bool isInverse) 
 {
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     if (column[cx] != NULL) {
       column[cx]->scale(vect1, isInverse); 
     }
@@ -568,8 +505,7 @@ void AzDmat::scale(const AzDvect *vect1, bool isInverse)
 bool AzDmat::isZero() const
 {
   if (column == NULL) return true; 
-  int cx; 
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     if (column[cx] != NULL && 
         !column[cx]->isZero()) { 
       return false; 
@@ -596,8 +532,7 @@ bool AzDmat::isZero(int col) const
 void AzDmat::convert(AzSmat *m_out)
 {
   m_out->reform(row_num, col_num); 
-  int col; 
-  for (col = 0; col < col_num; ++col) {
+  for (int col = 0; col < col_num; ++col) {
     if (column[col] != NULL) {
       AzIFarr ifq; 
       column[col]->nonZero(&ifq); 
@@ -638,8 +573,7 @@ void AzDvect::set(const AzSvect *v_inp)
   }
   reform(v_inp->row_num); 
   if (num > 0) {
-    int ix; 
-    for (ix = 0; ix < v_inp->elm_num; ++ix) {
+    for (int ix = 0; ix < v_inp->elm_num; ++ix) {
       elm[v_inp->elm[ix].no] = v_inp->elm[ix].val; 
     } 
   }
@@ -658,8 +592,7 @@ void AzDvect::resize(int new_num)
   if (new_num != old_num) {
     a.realloc(&elm, new_num, eyec, "elm"); 
   }
-  int ex; 
-  for (ex = old_num; ex < new_num; ++ex) {
+  for (int ex = old_num; ex < new_num; ++ex) {
     elm[ex] = 0; 
   }
 }
@@ -681,8 +614,7 @@ void AzDvect::_read(AzFile *file)
 void AzDvect::_swap()
 {
   if (!isSwapNeeded) return; 
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     AzFile::swap_double(&elm[ex]); 
   }
 }
@@ -701,8 +633,7 @@ void AzDvect::write(AzFile *file)
 /*-------------------------------------------------------------*/
 void AzDvect::binarize()
 {
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     if (elm[ex] > 0) {
       elm[ex] = 1; 
     }
@@ -715,8 +646,7 @@ void AzDvect::binarize()
 /*-------------------------------------------------------------*/
 void AzDvect::binarize1()
 {
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     if (elm[ex] != 0) {
       elm[ex] = 1; 
     }
@@ -726,8 +656,7 @@ void AzDvect::binarize1()
 /*-------------------------------------------------------------*/
 bool AzDvect::isZero() const
 {
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     if (elm[ex] != 0) {
       return false; 
     }
@@ -740,22 +669,20 @@ void AzDvect::values(const int exs[],
                      int ex_num, 
                      AzIFarr *ifa_ex_value) /* output */
 {
-  ifa_ex_value->prepare(ex_num); 
-  int ix; 
-  for (ix = 0; ix < ex_num; ++ix) {
-    int ex = exs[ix]; 
+  ifa_ex_value->prepare(ex_num);
+  for (int ix = 0; ix < ex_num; ++ix) {
+    int ex = exs[ix];
     if (ex < 0 || ex >= num) {
-      throw new AzException("AzDvect:;getValues", "Out of range"); 
+      throw new AzException("AzDvect:;getValues", "Out of range");
     }
-    ifa_ex_value->put(ex, elm[ex]); 
+    ifa_ex_value->put(ex, elm[ex]);
   }
 }
 
 /*-------------------------------------------------------------*/
 void AzDvect::nonZeroRowNo(AzIntArr *iq) const
 {
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     if (elm[ex] != 0) {
       iq->put(ex); 
     }
@@ -765,8 +692,7 @@ void AzDvect::nonZeroRowNo(AzIntArr *iq) const
 /*-------------------------------------------------------------*/
 void AzDvect::nonZero(AzIFarr *ifq) const
 {
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     if (elm[ex] != 0) {
       ifq->put(ex, elm[ex]); 
     }
@@ -777,8 +703,7 @@ void AzDvect::nonZero(AzIFarr *ifq) const
 int AzDvect::nonZeroRowNum() const
 {
   int count = 0; 
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     if (elm[ex] != 0) {
       ++count;  
     }
@@ -797,8 +722,7 @@ double AzDvect::max(const AzIntArr *ia_dx, int *out_no) const
 
   double max_val = -1; 
   int max_row = -1; 
-  int ix; 
-  for (ix = 0; ix < dx_num; ++ix) {
+  for (int ix = 0; ix < dx_num; ++ix) {
     int ex = ix; 
     if (dxs != NULL) {
       ex = dxs[ix]; 
@@ -819,8 +743,7 @@ double AzDvect::max(int *out_no) const
 {
   double max_val = -1; 
   int max_row = -1; 
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     if (max_row < 0 || elm[ex] > max_val) {
       max_val = elm[ex]; 
       max_row = ex; 
@@ -838,8 +761,7 @@ double AzDvect::maxAbs(int *out_row,
 {
   double real_val = -1, max_val = -1; 
   int max_row = -1; 
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     double abs_val = fabs(elm[ex]); 
     if (max_row < 0 || abs_val > max_val) {
       max_val = abs_val; 
@@ -865,54 +787,52 @@ double AzDvect::maxAbs(int *out_row,
 /*-------------------------------------------------------------*/
 double AzDvect::min(const AzIntArr *ia_dx, int *out_no) const
 {
-  const int *dxs = NULL; 
-  int dx_num = num; 
+  const int *dxs = NULL;
+  int dx_num = num;
   if (ia_dx != NULL) {
-    dxs = ia_dx->point(&dx_num); 
+    dxs = ia_dx->point(&dx_num);
   }
-  double min_val = -1; 
-  int min_row = -1; 
-  int ix; 
-  for (ix = 0; ix < dx_num; ++ix) {
+  double min_val = -1;
+  int min_row = -1;
+  for (int ix = 0; ix < dx_num; ++ix) {
     int ex = ix; 
     if (dxs != NULL) {
-      ex = dxs[ix]; 
+      ex = dxs[ix];
     }
     if (min_row < 0 || elm[ex] < min_val) {
-      min_val = elm[ex]; 
-      min_row = ex; 
+      min_val = elm[ex];
+      min_row = ex;
     }
   }
   if (out_no != NULL) {
-    *out_no = min_row; 
+    *out_no = min_row;
   }
-  return min_val; 
+  return min_val;
 }
 
 /*-------------------------------------------------------------*/
 double AzDvect::min(int *out_no) const
 {
-  double min_val = -1; 
-  int min_row = -1; 
-  int ex; 
+  double min_val = -1;
+  int min_row = -1;
+  int ex;
   for (ex = 0; ex < num; ++ex) {
     if (min_row < 0 || elm[ex] < min_val) {
-      min_val = elm[ex]; 
-      min_row = ex; 
+      min_val = elm[ex];
+      min_row = ex;
     }
   }
   if (out_no != NULL) {
-    *out_no = min_row; 
+    *out_no = min_row;
   }
-  return min_val; 
+  return min_val;
 }
 
 /*-------------------------------------------------------------*/
-void AzDvect::set(double val) 
+void AzDvect::set(double val)
 {
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
-    this->elm[ex] = val; 
+  for (int ex = 0; ex < num; ++ex) {
+    this->elm[ex] = val;
   }
 }
 
@@ -920,19 +840,17 @@ void AzDvect::set(double val)
 double AzDvect::sum() const
 {
   double sum = 0; 
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
-    sum += elm[ex]; 
+  for (int ex = 0; ex < num; ++ex) {
+    sum += elm[ex];
   }
-  return sum; 
+  return sum;
 }
 
 /*-------------------------------------------------------------*/
 double AzDvect::sum(const int *row, int r_num) const
 {
   double sum = 0; 
-  int ix; 
-  for (ix = 0; ix < r_num; ++ix) {
+  for (int ix = 0; ix < r_num; ++ix) {
     int ex = row[ix]; 
     if (ex < 0 || ex >= num) {
       throw new AzException("AzDvect::sum", "out of range"); 
@@ -946,8 +864,7 @@ double AzDvect::sum(const int *row, int r_num) const
 double AzDvect::absSum(const int *row, int r_num) const
 {
   double sum = 0; 
-  int ix; 
-  for (ix = 0; ix < r_num; ++ix) {
+  for (int ix = 0; ix < r_num; ++ix) {
     int ex = row[ix]; 
     if (ex < 0 || ex >= num) {
       throw new AzException("AzDvect::sum", "out of range"); 
@@ -961,8 +878,7 @@ double AzDvect::absSum(const int *row, int r_num) const
 double AzDvect::absSum() const
 {
   double sum = 0; 
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     sum += fabs(elm[ex]); 
   }
   return sum; 
@@ -973,8 +889,7 @@ void AzDvect::add(double val,
                   const int *row, int r_num) 
 {
   if (row == NULL) return; 
-  int ix; 
-  for (ix = 0; ix < r_num; ++ix) {
+  for (int ix = 0; ix < r_num; ++ix) {
     int ex = row[ix]; 
     if (ex < 0 || ex >= num) {
       throw new AzException("AzDvet::add(val,ia)", "index is out of range"); 
@@ -986,8 +901,7 @@ void AzDvect::add(double val,
 /*--------------------------------------------------------*/
 void AzDvect::add(double val) 
 {
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     elm[ex] += val; 
   }
 }
@@ -996,8 +910,7 @@ void AzDvect::add(double val)
 void AzDvect::add_nochk(double val, 
                   const int *row, int r_num) 
 {
-  int ix; 
-  for (ix = 0; ix < r_num; ++ix) {
+  for (int ix = 0; ix < r_num; ++ix) {
     int ex = row[ix]; 
     elm[ex] += val; 
   }
@@ -1010,33 +923,13 @@ void AzDvect::max_abs(const AzDvect *v)
   if (num != v->rowNum()) {
     throw new AzException(eyec, "shape mismatch"); 
   }
-  int ex;
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     double val = v->elm[ex]; 
     val = (val > 0) ? val : -val; 
     elm[ex] = MAX(elm[ex], val);     
   }
 }
 
-#if 0 
-/*-------------------------------------------------------------*/
-void AzDvect::max_abs(const AzReadOnlyVector *v) 
-{
-  const char *eyec = "AzDvect::max_abs"; 
-  if (num != v->rowNum()) {
-    throw new AzException(eyec, "shape mismatch"); 
-  }
-  AzCursor cur; 
-  for ( ; ; ) {
-    double val; 
-    int ex = v->next(cur, val); 
-    if (ex < 0) break; 
-    val = (val > 0) ? val : -val; 
-    elm[ex] = MAX(elm[ex], val);     
-  }
-}
-#endif 
- 
 /*-------------------------------------------------------------*/
 void AzDvect::add_abs(const AzDvect *v) 
 {
@@ -1044,8 +937,7 @@ void AzDvect::add_abs(const AzDvect *v)
   if (num != v->rowNum()) {
     throw new AzException(eyec, "shape mismatch"); 
   }
-  int ex;
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     if (v->elm[ex] > 0) {
       elm[ex] += v->elm[ex]; 
     }
@@ -1055,29 +947,6 @@ void AzDvect::add_abs(const AzDvect *v)
   }
 }
 
-#if 0 
-/*-------------------------------------------------------------*/
-void AzDvect::add_abs(const AzReadOnlyVector *v) 
-{
-  const char *eyec = "AzDvect::add_abs"; 
-  if (num != v->rowNum()) {
-    throw new AzException(eyec, "shape mismatch"); 
-  }
-  AzCursor cur; 
-  for ( ; ; ) {
-    double val; 
-    int ex = v->next(cur, val); 
-    if (ex < 0) break; 
-    if (val > 0) {
-      elm[ex] += val; 
-    }
-    else {
-      elm[ex] -= val; 
-    }
-  }
-}
-#endif 
-
 /*-------------------------------------------------------------*/
 /* WARNING: This could be very slow.  */
 void AzDvect::add(const AzReadOnlyVector *vect1, double coefficient) 
@@ -1120,8 +989,7 @@ void AzDvect::add(const AzSvect *vect1, double coefficient)
   }
   if (vect1->elm == NULL) return; 
 
-  int ix; 
-  for (ix = 0; ix < vect1->elm_num; ++ix) {
+  for (int ix = 0; ix < vect1->elm_num; ++ix) {
     double val = vect1->elm[ix].val; 
     if (val != 0) {
       elm[vect1->elm[ix].no] += coefficient * vect1->elm[ix].val; 
@@ -1159,8 +1027,7 @@ void AzDvect::multiply(double val)
     return; 
   }
 
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     this->elm[ex] *= val; 
   }
 }
@@ -1173,8 +1040,7 @@ void AzDvect::scale(const AzDvect *dbles1, bool isInverse)
   if (num != dbles1->num) {
     throw new AzException(eyec, "shape mismatch"); 
   }
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     if (elm[ex] != 0) {
       if (dbles1->elm[ex] == 0) elm[ex] = 0; 
       else if (dbles1->elm[ex] != 1) {
@@ -1197,8 +1063,7 @@ void AzDvect::scale(const AzSvect *vect1, bool isInverse)
   }
 
   int last_ex = -1; 
-  int ix; 
-  for (ix = 0; ix < vect1->elm_num; ++ix) {
+  for (int ix = 0; ix < vect1->elm_num; ++ix) {
     double val = vect1->elm[ix].val; 
     int ex = vect1->elm[ix].no; 
 
@@ -1230,8 +1095,7 @@ void AzDvect::scale(const AzSvect *vect1, bool isInverse)
 double AzDvect::selfInnerProduct() const
 {
   double n2 = 0; 
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     if (elm[ex] != 0) {
       n2 += (elm[ex] * elm[ex]); 
     }
@@ -1281,8 +1145,7 @@ double AzDvect::innerProduct(const AzSvect *vect1) const
   }
 
   double iprod = 0; 
-  int ix; 
-  for (ix = 0; ix < vect1->elm_num; ++ix) {
+  for (int ix = 0; ix < vect1->elm_num; ++ix) {
     double val = vect1->elm[ix].val; 
     if (val != 0) {
       iprod += val * elm[vect1->elm[ix].no]; 
@@ -1306,8 +1169,7 @@ double AzDvect::innerProduct(const AzDvect *dbles1) const
   }
 
   double iprod = 0; 
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     iprod += (elm[ex] * dbles1->elm[ex]); 
   }
 
@@ -1317,15 +1179,14 @@ double AzDvect::innerProduct(const AzDvect *dbles1) const
 /*-------------------------------------------------------------*/
 double AzDvect::normalize()
 {
-  int ex; 
   double norm2 = 0; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     norm2 += (elm[ex] * elm[ex]); 
   }
 
   if (norm2 != 0) {
     norm2 = sqrt(norm2); 
-    for (ex = 0; ex < num; ++ex) {
+    for (int ex = 0; ex < num; ++ex) {
       elm[ex] /= norm2; 
     }
   }
@@ -1335,14 +1196,13 @@ double AzDvect::normalize()
 /*-------------------------------------------------------------*/
 double AzDvect::normalize1()
 {
-  int ex; 
   double sum = 0; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     sum += elm[ex]; 
   }
 
   if (sum != 0) {
-    for (ex = 0; ex < num; ++ex) {
+    for (int ex = 0; ex < num; ++ex) {
       elm[ex] /= sum; 
     }
   }
@@ -1431,8 +1291,7 @@ void AzDvect::_dump(const AzOut &out,
   ifa_nz.sort_Float(false); 
   ifa_nz.cut(cut_num); 
   int num = ifa_nz.size(); 
-  int ix; 
-  for (ix = 0; ix < num; ++ix) {
+  for (int ix = 0; ix < num; ++ix) {
     int row; 
     double val = ifa_nz.get(ix, &row); 
 
@@ -1452,8 +1311,7 @@ void AzDvect::_dump(const AzOut &out,
 /*-------------------------------------------------------------*/
 void AzDvect::cut(double min_val)
 {
-  int ex; 
-  for (ex = 0; ex < num; ++ex) {
+  for (int ex = 0; ex < num; ++ex) {
     if (fabs(elm[ex]) < min_val) {
       elm[ex] = 0; 
     }
@@ -1463,14 +1321,11 @@ void AzDvect::cut(double min_val)
 /*-------------------------------------------------------------*/
 void AzDvect::load(const AzIFarr *ifa_row_val)
 {
-  int ix; 
-  for (ix = 0; ix < num; ++ix) {
+  for (int ix = 0; ix < num; ++ix) {
     elm[ix] = 0; 
   }
 
-  int data_num = ifa_row_val->size(); 
-
-  for (ix = 0; ix < data_num; ++ix) {
+  for (int ix = 0; ix < ifa_row_val->size(); ++ix) {
     int row; 
     double val = ifa_row_val->get(ix, &row);     
     if (row < 0 || row >= num) { /* out of range */
@@ -1484,8 +1339,7 @@ void AzDvect::load(const AzIFarr *ifa_row_val)
 /*-------------------------------------------------------------*/
 void AzDvect::square()
 {
-  int ix; 
-  for (ix = 0; ix < num; ++ix) {
+  for (int ix = 0; ix < num; ++ix) {
     elm[ix] = elm[ix] * elm[ix]; 
   }
 }
@@ -1493,8 +1347,7 @@ void AzDvect::square()
 /*-------------------------------------------------------------*/
 void AzDmat::square()
 {
-  int col; 
-  for (col = 0; col < col_num; ++col) {
+  for (int col = 0; col < col_num; ++col) {
     if (column[col] != NULL) {
       column[col]->square(); 
     }
@@ -1509,8 +1362,7 @@ void AzDmat::average_sdev(AzDvect *v_avg,
   if (v_sdev != NULL) v_sdev->reform(row_num); 
   if (col_num <= 0) return; 
   AzDvect v_avg2(row_num); 
-  int cx;
-  for (cx = 0; cx < col_num; ++cx) {
+  for (int cx = 0; cx < col_num; ++cx) {
     v_avg->add(col(cx)); 
     if (v_sdev != NULL) {
       AzDvect v(col(cx)); v.square(); 
@@ -1529,8 +1381,7 @@ void AzDvect::rbind(const AzDvect *v) {
   int old_num = rowNum(); 
   int new_num = old_num + v->rowNum(); 
   resize(new_num);
-  int ex;
-  for (ex = 0; ex < v->rowNum(); ++ex) {
+  for (int ex = 0; ex < v->rowNum(); ++ex) {
     elm[old_num+ex] = v->elm[ex]; 
   }
 }
@@ -1541,8 +1392,7 @@ void AzDmat::rbind(const AzDmat *m)
   if (m->colNum() != col_num) {
     throw new AzException("AzDmat::rbind", "#column must be the same"); 
   }
-  int col; 
-  for (col = 0; col < col_num; ++col) {
+  for (int col = 0; col < col_num; ++col) {
     column[col]->rbind(m->col(col)); 
   }
   row_num += m->rowNum(); 
@@ -1558,8 +1408,7 @@ void AzDmat::undo_rbind(int added_len)
     throw new AzException("AzDmat::rbind_rev", "#row is too small"); 
   }
   if (added_len <= 0) return; 
-  int col; 
-  for (col = 0; col < col_num; ++col) {
+  for (int col = 0; col < col_num; ++col) {
     AzDvect v(column[col]); 
     column[col]->set(column[col]->point(), row_num-added_len); 
   }
@@ -1573,11 +1422,10 @@ void AzDmat::undo_rbind(int added_len)
 void AzDvect::polarize() {
   int org_num = num; 
   resize(org_num*2); 
-  int ex;
-  for (ex = 0; ex < org_num; ++ex) {
+  for (int ex = 0; ex < org_num; ++ex) {
     if (elm[ex] < 0) {
-      elm[org_num+ex] = -elm[ex]; 
-      elm[ex] = 0; 
+      elm[org_num+ex] = -elm[ex];
+      elm[ex] = 0;
     }
   }
 }
@@ -1585,32 +1433,29 @@ void AzDvect::polarize() {
 /*-------------------------------------------------------------*/
 bool AzDvect::isSame(const AzReadOnlyVector *v) const {
   if (num != v->rowNum()) return false; 
-  int ex;
-  for (ex = 0; ex < num; ++ex) {
-    if (elm[ex] != v->get(ex)) return false; 
+  for (int ex = 0; ex < num; ++ex) {
+    if (elm[ex] != v->get(ex)) return false;
   }
-  return true; 
+  return true;
 }
 
 /*-------------------------------------------------------------*/
 bool AzDvect::isSame(const double *inp, int inp_num) const {
   if (num != inp_num) return false; 
-  int ex;
-  for (ex = 0; ex < num; ++ex) {
-    if (elm[ex] != inp[ex]) return false; 
+  for (int ex = 0; ex < num; ++ex) {
+    if (elm[ex] != inp[ex]) return false;
   }
-  return true; 
+  return true;
 }
 
 /*-------------------------------------------------------------*/
 bool AzDmat::isSame(const AzReadOnlyMatrix *m) const {
   if (m == NULL) throw new AzException("AzDmat::isSame", "null input"); 
   if (col_num != m->colNum() || row_num != m->rowNum()) return false;
-  int cx;
-  for (cx = 0; cx < col_num; ++cx) {
-    if (!column[cx]->isSame(m->col(cx))) return false; 
+  for (int cx = 0; cx < col_num; ++cx) {
+    if (!column[cx]->isSame(m->col(cx))) return false;
   }
-  return true; 
+  return true;
 }
 
 /*-------------------------------------------------------------*/
@@ -1621,18 +1466,17 @@ int AzDmat::set(const AzDmat *inp, const int *cols, int cnum,  /* new2old */
     reform(inp->row_num, cnum); 
   }
   int negaindex = 0; 
-  int my_col; 
-  for (my_col = 0; my_col < cnum; ++my_col) {
+  for (int my_col = 0; my_col < cnum; ++my_col) {
     int col = cols[my_col]; 
     if (col < 0 && do_zero_negaindex) {
-      column[my_col]->zeroOut();     
-      ++negaindex; 
-      continue; 
-    }   
-    if (col < 0 || col >= inp->col_num) {
-      throw new AzException("AzDmat::set(inp,cols,cnum)", "invalid col#"); 
+      column[my_col]->zeroOut();
+      ++negaindex;
+      continue;
     }
-    column[my_col]->set(inp->column[col]); 
+    if (col < 0 || col >= inp->col_num) {
+      throw new AzException("AzDmat::set(inp,cols,cnum)", "invalid col#");
+    }
+    column[my_col]->set(inp->column[col]);
   }
   return negaindex; 
 }
@@ -1652,8 +1496,7 @@ void AzDmat::set(int col0, int col1, const AzDmat *inp, int i_col0)
     throw new AzException(eyec, "#rows mismatch"); 
   }
   int i_col = i_col0; 
-  int col; 
-  for (col = col0; col < col1; ++col, ++i_col) {
+  for (int col = col0; col < col1; ++col, ++i_col) {
     column[col]->set(inp->column[i_col]);       
   }
 }  
@@ -1661,18 +1504,17 @@ void AzDmat::set(int col0, int col1, const AzDmat *inp, int i_col0)
 /*-------------------------------------------------------------*/
 void AzDmat::reduce(const int *cols, int cnum)  /* new2old */
 {
-  int new_col; 
-  for (new_col = 0; new_col < cnum; ++new_col) {
-    int old_col = cols[new_col];  
+  for (int new_col = 0; new_col < cnum; ++new_col) {
+    int old_col = cols[new_col];
     if (old_col < 0 || old_col >= col_num) {
-      throw new AzException("AzDmat::set(inp,cols,cnum)", "invalid col#"); 
+      throw new AzException("AzDmat::set(inp,cols,cnum)", "invalid col#");
     }
     if (new_col > 0 && old_col <= cols[new_col-1]) {
-      throw new AzException("AzDmat::set(inp,cols,cnum)", "col#'s must be sorted"); 
+      throw new AzException("AzDmat::set(inp,cols,cnum)", "col#'s must be sorted");
     }
     if (new_col != old_col) {
-      column[new_col]->set(column[old_col]); 
+      column[new_col]->set(column[old_col]);
     }
   }
-  resize(cnum); 
+  resize(cnum);
 }
