@@ -86,13 +86,11 @@ void AzFindSplit::_findBestSplit(int nx,
 
 /*--------------------------------------------------------*/
 double AzFindSplit::evalSplit(const Az_forFindSplit i[2],
-                              double bestP[2])
- const
+                              double bestP[2]) const
 {
-  double gain = 0; 
-  gain += getBestGain(i[0].w_sum, i[0].wy_sum, &bestP[0]); 
-  gain += getBestGain(i[1].w_sum, i[1].wy_sum, &bestP[1]); 
-  return gain; 
+  double gain = getBestGain(i[0].w_sum, i[0].wy_sum, &bestP[0]);
+  gain += getBestGain(i[1].w_sum, i[1].wy_sum, &bestP[1]);
+  return gain;
 }
 
 /*--------------------------------------------------------*/
@@ -107,9 +105,10 @@ void AzFindSplit::loop(AzTrTsplit *best_split,
 
   int dest_size = 0; 
   Az_forFindSplit i[2];
-  Az_forFindSplit *src = &i[1], *dest = &i[0]; 
-  double bestP[2] = {0,0}; 
-  int le_idx, gt_idx; 
+  Az_forFindSplit *src = &i[1];
+  Az_forFindSplit *dest = &i[0];
+
+  int le_idx, gt_idx;
   if (sorted->isForward()) {
     le_idx = 0; 
     gt_idx = 1; 
@@ -136,8 +135,7 @@ void AzFindSplit::loop(AzTrTsplit *best_split,
     const double *tarDw = target->tarDw_arr(); 
     const double *dw = target->dw_arr(); 
     double wy_sum_move = 0, w_sum_move = 0; 
-    int ix; 
-    for (ix = 0; ix < index_num; ++ix) {
+    for (int ix = 0; ix < index_num; ++ix) {
       int dx = index[ix]; 
       wy_sum_move += tarDw[dx]; 
       w_sum_move += dw[dx]; 
@@ -157,16 +155,12 @@ void AzFindSplit::loop(AzTrTsplit *best_split,
     src->wy_sum = total->wy_sum - dest->wy_sum; 
     src->w_sum  = total->w_sum  - dest->w_sum; 
 
+    double bestP[2] = {0, 0};
     const double gain = evalSplit(i, bestP);
-#if 0 
-    best_split->keep_if_good(fx, value, gain, 
-                        bestP[le_idx], bestP[gt_idx]); 
-#else
     if (gain > best_split->gain) {
-      best_split->reset_values(fx, value, gain, 
-                        bestP[le_idx], bestP[gt_idx]); 
+      best_split->reset_values(fx, value, gain,
+                               bestP[le_idx], bestP[gt_idx]);
     }
-#endif 
   }
 }
 
@@ -174,25 +168,24 @@ void AzFindSplit::loop(AzTrTsplit *best_split,
 void AzFindSplit::_pickFeats(int pick_num, int f_num)
 {
   if (pick_num < 1 || pick_num > f_num) {
-    throw new AzException("AzFindSplit::pickFeats", "out of range"); 
+    throw new AzException("AzFindSplit::pickFeats", "out of range");
   }
-  ia_feats.reset(); 
+  ia_feats.reset();
   if (pick_num == f_num) {
-    ia_fx = NULL; 
-    return; 
+    ia_fx = NULL;
+    return;
   }
 
-  AzIntArr ia_onOff; 
-  ia_onOff.reset(f_num, 0); 
-  int *onOff = ia_onOff.point_u(); 
+  AzIntArr ia_onOff;
+  ia_onOff.reset(f_num, 0);
+  int *onOff = ia_onOff.point_u();
   for ( ; ; ) {
-    if (ia_feats.size() >= pick_num) break; 
-    int fx = rand() % f_num; 
+    if (ia_feats.size() >= pick_num) break;
+    int fx = rand() % f_num;
     if (onOff[fx] == 0) {
-      onOff[fx] = 1; 
-      ia_feats.put(fx); 
+      onOff[fx] = 1;
+      ia_feats.put(fx);
     }
   }
-  ia_fx = &ia_feats; 
+  ia_fx = &ia_feats;
 }
- 
