@@ -25,9 +25,9 @@
 #include "AzHelp.hpp"
 #include "AzTETproc.hpp"
 
-static int exe_argx = 0; 
-static int action_argx = 1; 
-static int config_argx = 2; 
+static const int exe_argx = 0;
+static const int action_argx = 1;
+static const int config_argx = 2;
 
 static const char *pred_fn_suffix = ".pred"; 
 static const char *info_fn_suffix = ".info"; 
@@ -85,8 +85,7 @@ void AzTETmain::readData(const char *x_fn,
                          /*---  output  ---*/
                          AzSmat *m_x, 
                          AzDvect *v_y, 
-                         AzSvFeatInfoClone *featInfo) /* may be NULL */
-const 
+                         AzSvFeatInfoClone *featInfo) /* may be NULL */ const
 {
   AzSvDataS dataset; 
   dataset.read(x_fn, y_fn, fdic_fn); 
@@ -100,8 +99,7 @@ const
 /*------------------------------------------------------------------*/
 void AzTETmain::readDataWeights(AzBytArr &s_fn, 
                             int data_num, 
-                            AzDvect *v_fixed_dw)
-const
+                            AzDvect *v_fixed_dw) const
 {
   if (s_fn.length() <= 0) return; 
   AzSvDataS::readVector(s_fn.c_str(), v_fixed_dw); 
@@ -172,10 +170,9 @@ void AzTETmain::writePrediction_single(const AzDvect *v_p,
                                        AzFile *file)
 {
   /* one prediction value per line */
-  int width = 8; 
-  AzBytArr s; 
-  int dx; 
-  for (dx = 0; dx < v_p->rowNum(); ++dx) {
+  const int width = 8;
+  AzBytArr s;
+  for (int dx = 0; dx < v_p->rowNum(); ++dx) {
     double val = v_p->get(dx); 
     s.concatFloat(val, width); 
     s.nl(); /* new line */
@@ -254,9 +251,7 @@ void AzTETmain::batch_predict(const char *argv[], int argc)
   AzStrPool sp_model_fn; 
   AzTools::readList(s_model_names_fn.c_str(), 
                     &sp_model_fn); 
-  int num = sp_model_fn.size(); 
-  int ix; 
-  for (ix = 0; ix < num; ++ix) {
+  for (int ix = 0; ix < sp_model_fn.size(); ++ix) {
     const char *model_fn = sp_model_fn.c_str(ix); 
     AzBytArr s_pred_fn(model_fn); 
     s_pred_fn.concat(&s_pred_fn_suffix); 
@@ -585,7 +580,8 @@ void AzTETmain::checkParam_train(bool for_train_test) const
 /*------------------------------------------------*/
 bool AzTETmain::resetParam_train_predict(const char *argv[], int argc)
 {
-  bool for_train_test = false, for_train_predict = true; 
+  bool for_train_test = false;
+  bool for_train_predict = true;
 
   if (argc-config_argx != 1) {
     printHelp_train(log_out, argv, argc, for_train_test, for_train_predict); 
@@ -674,10 +670,15 @@ const
   h.nl(); 
   AzBytArr s_kw(action); 
   AzBytArr s_desc; 
-  if      (s_action.compare(kw_train) == 0)         s_desc.c(help_train); 
-  else if (s_action.compare(kw_train_test) == 0)    s_desc.c(help_train_test); 
-  else if (s_action.compare(kw_predict) == 0)       s_desc.c(help_predict); 
-  else if (s_action.compare(kw_batch_predict) == 0) s_desc.c(help_batch_predict); 
+  if (s_action.compare(kw_train) == 0) {
+    s_desc.c(help_train);
+  } else if (s_action.compare(kw_train_test) == 0) {
+    s_desc.c(help_train_test);
+  } else if (s_action.compare(kw_predict) == 0) {
+    s_desc.c(help_predict);
+  } else if (s_action.compare(kw_batch_predict) == 0) {
+    s_desc.c(help_batch_predict);
+  }
   if (s_desc.length() > 0) {
     h.item(s_kw.c_str(), s_desc.c_str()); 
   }
@@ -830,7 +831,7 @@ bool AzTETmain::resetParam_batch_predict(const char *argv[], int argc)
 {
   if (argc-config_argx != 1) {
     printHelp_batch_predict(log_out, argv, argc); 
-    return false; /* faied */
+    return false; /* failed */
   }
 
   const char *param = argv[config_argx]; 
@@ -882,23 +883,23 @@ void AzTETmain::printParam_batch_predict(const AzOut &out) const
 void AzTETmain::printHelp_batch_predict(const AzOut &out, 
                 const char *argv[], int argc) const
 {
-  print_usage(out, argv, argc); 
+  print_usage(out, argv, argc);
 
   /*---  driver config  ---*/
   AzHelp h(out);
 
-  h.begin("batch_predict", "AzTETmain"); 
-  h.item_required(kw_model_names_fn, help_model_names_fn_inp); 
-  h.item_required(kw_test_x_fn, help_test_x_fn); 
-  h.item_required(kw_pred_fn_suffix, help_pred_fn_suffix); 
+  h.begin("batch_predict", "AzTETmain");
+  h.item_required(kw_model_names_fn, help_model_names_fn_inp);
+  h.item_required(kw_test_x_fn, help_test_x_fn);
+  h.item_required(kw_pred_fn_suffix, help_pred_fn_suffix);
 
-  h.nl(); 
-  h.writeln_header("To optionally evaluate the prediction values: "); 
-  h.item(kw_test_y_fn, help_test_y_fn); 
-  h.item(kw_eval_fn, help_eval_fn, "stdout"); 
-  h.item_experimental(kw_doAppend_eval, help_doAppend_eval); 
-  h.item_experimental(kw_not_doLog, help_not_doLog); 
-  h.item_experimental(kw_doDump, help_doDump); 
+  h.nl();
+  h.writeln_header("To optionally evaluate the prediction values: ");
+  h.item(kw_test_y_fn, help_test_y_fn);
+  h.item(kw_eval_fn, help_eval_fn, "stdout");
+  h.item_experimental(kw_doAppend_eval, help_doAppend_eval);
+  h.item_experimental(kw_not_doLog, help_not_doLog);
+  h.item_experimental(kw_doDump, help_doDump);
 
   h.end(); 
 }
@@ -1129,7 +1130,7 @@ bool AzTETmain::resetParam_features(const char *argv[], int argc)
 {
   if (argc-config_argx != 1) {
     printHelp_features(log_out, argv, argc); 
-    return false; /* faied */
+    return false; /* failed */
   }
 
   const char *param = argv[config_argx]; 
@@ -1186,3 +1187,172 @@ void AzTETmain::printHelp_features(const AzOut &out,
   h.item(kw_doSparse_features, help_doSparse_features); 
   h.end(); 
 }
+
+/*------------------------------------------------*/
+void AzTETmain::dump_model(const char *argv[], int argc)
+{
+  bool success = resetParam_dump_model(argv, argc);
+  if (!success) return;
+
+  printParam_dump_model(log_out);
+  checkParam_dump_model();
+
+  AzTimeLog::print("Dump model ... ", log_out);
+  AzTreeEnsemble ens(s_model_fn.c_str());
+  AzOut o;
+  ens.show(NULL, log_out, "");
+
+  AzTimeLog::print("Done ... ", log_out);
+}
+
+void AzTETmain::checkParam_dump_model() const
+{
+  const char *eyec = "AzTETmain::checkParam_dump_model";
+  throw_if_missing(kw_model_fn, s_model_fn, eyec);
+}
+
+void AzTETmain::printParam_dump_model(const AzOut &out) const
+{
+  if (out.isNull()) return;
+  AzPrint o(out);
+
+  o.ppBegin("AzTETmain::dump_model", "\"dump_model\"");
+  o.printV(kw_model_fn, s_model_fn);
+  o.ppEnd();
+}
+
+void AzTETmain::printHelp_dump_model(const AzOut &out,
+                const char *argv[], int argc) const
+{
+  print_usage(out, argv, argc);
+
+  AzHelp h(out);
+  h.begin("dump model", "AzTETmain");
+  h.item_required(kw_model_fn, help_model_fn);
+  h.nl();
+  h.end();
+}
+
+bool AzTETmain::resetParam_dump_model(const char *argv[], int argc)
+{
+  if (argc-config_argx != 1) {
+    printParam_dump_model(log_out);
+    return false; /* failed */
+  }
+
+  const char *param = argv[config_argx];
+  if (isHelpNeeded(param)) {
+    printHelp_dump_model(log_out, argv, argc);
+    return false; /* failed */
+  }
+
+  AzParam p(param);
+
+  p.vStr(kw_model_fn, &s_model_fn);
+  p.check(log_out);
+
+  return true;
+}
+
+/*------------------------------------------------*/
+void AzTETmain::feature_importances(const char *argv[], int argc)
+{
+  bool success = resetParam_feature_importances(argv, argc);
+  if (!success) return;
+
+  printParam_feature_importances(log_out);
+  checkParam_feature_importances();
+
+  AzTimeLog::print("Feature importances ... ", log_out);
+  AzTreeEnsemble ens(s_model_fn.c_str());
+
+  // To get feature num
+  AzTimeLog::print("Reading test data ... ", log_out);
+  AzSvDataS dataset;
+
+  dataset.read_features_only(s_train_x_fn.c_str());
+
+  double total = 0;
+  AzDvect v_feature_importances;  //get feat num
+  v_feature_importances.resize(dataset.featNum());
+  v_feature_importances.zeroOut();
+
+  for (int tx=0; tx < ens.size(); ++tx) {
+    const AzTree* tree = ens.tree(tx);
+    for (int nx=0; nx < tree->nodeNum(); ++nx) {
+      const AzTreeNode* node = tree->node(nx);
+      if (node->fx == -1) {
+        continue;
+      }
+      total += node->gain;
+      v_feature_importances.add(node->fx, node->gain);
+    }
+  }
+  v_feature_importances.divide(v_feature_importances.sum());
+
+  /*---  write feature importances  ---*/
+  AzFile fi_file(s_fi_fn.c_str());
+  fi_file.open("wb");
+  writePrediction_single(&v_feature_importances, &fi_file);
+  fi_file.close(true);
+
+  AzTimeLog::print("Done ... ", log_out);
+}
+
+void AzTETmain::checkParam_feature_importances() const
+{
+  const char *eyec = "AzTETmain::checkParam_feature_importances";
+  throw_if_missing(kw_model_fn, s_model_fn, eyec);
+  throw_if_missing(kw_train_x_fn, s_train_x_fn, eyec);
+  throw_if_missing(kw_fi_fn, s_fi_fn, eyec);
+}
+
+void AzTETmain::printParam_feature_importances(const AzOut &out) const
+{
+  if (out.isNull()) return;
+  AzPrint o(out);
+
+  o.ppBegin("AzTETmain::feature_importances", "\"feature_importances\"");
+  o.printV(kw_model_fn, s_model_fn);
+  o.printV(kw_train_x_fn, s_train_x_fn);
+  o.printV(kw_fi_fn, s_fi_fn);
+  o.ppEnd();
+}
+
+void AzTETmain::printHelp_feature_importances(const AzOut &out,
+                                              const char *argv[], int argc) const
+{
+  print_usage(out, argv, argc);
+
+  AzHelp h(out);
+  h.begin("feature importances", "AzTETmain");
+  h.item_required(kw_model_fn, help_model_fn);
+  h.item_required(kw_train_x_fn, help_train_x_fn);
+  h.item_required(kw_fi_fn, help_fi_fn);
+  h.nl();
+  h.end();
+}
+
+
+bool AzTETmain::resetParam_feature_importances(const char *argv[], int argc)
+{
+  if (argc-config_argx != 1) {
+    printHelp_feature_importances(log_out, argv, argc);
+    return false; /* failed */
+  }
+
+  const char *param = argv[config_argx];
+  if (isHelpNeeded(param)) {
+    printHelp_feature_importances(log_out, argv, argc);
+    return false; /* failed */
+  }
+
+  AzParam p(param);
+
+  p.vStr(kw_train_x_fn, &s_train_x_fn);
+  p.vStr(kw_fi_fn, &s_fi_fn);
+  p.vStr(kw_model_fn, &s_model_fn);
+  p.check(log_out);
+
+  return true;
+}
